# Things to keep in mind for distributed computing


# Messaging Frameworks

- http://zeromq.org/
- https://gstreamer.freedesktop.org
- https://abhitronix.github.io/vidgear/latest/gears/camgear/usage/
